@@ -67,7 +67,6 @@ typedef enum {
   DT_H5T_STD_B64LE,
   DT_H5T_STD_REF_OBJ,
   DT_H5T_STD_REF_DSETREG,
-  DT_H5T_STD_REF,
   DT_H5T_UNIX_D32BE,
   DT_H5T_UNIX_D32LE,
   DT_H5T_UNIX_D64BE,
@@ -190,7 +189,6 @@ typedef enum {
   DT_time_t,
   DT_uint32_t,
   DT_uint64_t,
-  DT_uint8_t,
   DT_unsigned,
   DT_unsigned_char,
   DT_unsigned_int,
@@ -217,10 +215,8 @@ typedef enum {
   DT_H5D_vds_view_t,
   DT_H5E_direction_t,
   DT_H5E_type_t,
-  DT_H5ES_status_t,
   DT_H5F_close_degree_t,
   DT_H5F_file_space_type_t,
-  DT_H5F_fspace_strategy_t,
   DT_H5F_libver_t,
   DT_H5F_mem_t,
   DT_H5F_scope_t,
@@ -250,17 +246,13 @@ typedef enum {
   DT_H5T_pers_t,
   DT_H5T_sign_t,
   DT_H5T_str_t,
-  DT_H5VL_map_get_t,
-  DT_H5VL_map_specific_t,
   DT_H5Z_cb_return_t,
   DT_H5Z_EDC_t,
   DT_H5Z_SO_scale_type_t,
-  DT_H5L_info1_helper_t,
-  DT_H5L_info2_helper_t,
+  DT_H5L_info_helper_t,
   DT_H5_ih_info_t,
   DT_H5A_info_t,
   DT_H5AC_cache_config_t,
-  DT_H5AC_cache_image_config_t,
   DT_H5D_info_t,
   DT_H5E_error1_t,
   DT_H5E_error2_t,
@@ -273,21 +265,14 @@ typedef enum {
   DT_H5F_retry_info_t,
   DT_H5F_sect_info_t,
   DT_H5G_info_t,
-  DT_H5L_info1_t,
-  DT_H5L_info2_t,
+  DT_H5L_info_t,
   DT_H5ls_info_t,
   DT_H5O_hdr_info_helper_msg_t,
   DT_H5O_hdr_info_helper_space_t,
   DT_H5O_hdr_info_t,
   DT_H5O_info_helper_t,
-  DT_H5O_info1_t,
-  DT_H5O_info2_t,
-  DT_H5O_native_info_t,
+  DT_H5O_info_t,
   DT_H5O_stat_t,
-  DT_H5O_token_t,
-  DT_H5R_ref_helper_t,
-  DT_H5R_ref_t,
-  DT_hdset_reg_ref_t,
 #if H5_SIZEOF_LONG_DOUBLE !=0
   DT_H5T_NATIVE_LDOUBLE,
 #endif
@@ -338,10 +323,10 @@ hid_t create_DT_H5D_layout_t(void);
 /* typedef enum H5D_mpio_actual_chunk_opt_mode_t { H5D_MPIO_NO_CHUNK_OPTIMIZATION = 0, H5D_MPIO_LINK_CHUNK, H5D_MPIO_MULTI_CHUNK} H5D_mpio_actual_chunk_opt_mode_t; */
 hid_t create_DT_H5D_mpio_actual_chunk_opt_mode_t(void);
 
-/* typedef enum H5D_mpio_actual_io_mode_t { H5D_MPIO_NO_COLLECTIVE = 0x0, H5D_MPIO_CHUNK_INDEPENDENT = 0x1, H5D_MPIO_CHUNK_COLLECTIVE = 0x2, H5D_MPIO_CHUNK_MIXED = 0x1 | 0x2, H5D_MPIO_CONTIGUOUS_COLLECTIVE = 0x4} H5D_mpio_actual_io_mode_t; */
+/* typedef enum H5D_mpio_actual_io_mode_t { H5D_MPIO_NO_COLLECTIVE = 0x0, H5D_MPIO_CHUNK_INDEPENDENT = 0x1, H5D_MPIO_CHUNK_COLLECTIVE = 0x2, H5D_MPIO_CHUNK_MIXED = 0x1 | 0x2, H5D_MPIO_CONTIGUOUS_COLLECTIVE = 0x4} H5D_mpio_actual_io_mode_t;  */
 hid_t create_DT_H5D_mpio_actual_io_mode_t(void);
 
-/* typedef enum H5D_mpio_no_collective_cause_t { H5D_MPIO_COLLECTIVE = 0x00, H5D_MPIO_SET_INDEPENDENT = 0x01, H5D_MPIO_DATATYPE_CONVERSION = 0x02, H5D_MPIO_DATA_TRANSFORMS = 0x04, H5D_MPIO_MPI_OPT_TYPES_ENV_VAR_DISABLED = 0x08, H5D_MPIO_NOT_SIMPLE_OR_SCALAR_DATASPACES = 0x10, H5D_MPIO_NOT_CONTIGUOUS_OR_CHUNKED_DATASET = 0x20, H5D_MPIO_PARALLEL_FILTERED_WRITES_DISABLED = 0x40, H5D_MPIO_ERROR_WHILE_CHECKING_COLLECTIVE_POSSIBLE = 0x80, H5D_MPIO_NO_COLLECTIVE_MAX_CAUSE = 0x100} H5D_mpio_no_collective_cause_t; */
+/* typedef enum H5D_mpio_no_collective_cause_t { H5D_MPIO_COLLECTIVE = 0x00, H5D_MPIO_SET_INDEPENDENT = 0x01, H5D_MPIO_DATATYPE_CONVERSION = 0x02, H5D_MPIO_DATA_TRANSFORMS = 0x04, H5D_MPIO_MPI_OPT_TYPES_ENV_VAR_DISABLED = 0x08, H5D_MPIO_NOT_SIMPLE_OR_SCALAR_DATASPACES = 0x10, H5D_MPIO_NOT_CONTIGUOUS_OR_CHUNKED_DATASET = 0x20, H5D_MPIO_FILTERS = 0x40} H5D_mpio_no_collective_cause_t; */
 hid_t create_DT_H5D_mpio_no_collective_cause_t(void);
 
 /* typedef enum H5D_space_status_t { H5D_SPACE_STATUS_ERROR = -1, H5D_SPACE_STATUS_NOT_ALLOCATED = 0, H5D_SPACE_STATUS_PART_ALLOCATED = 1, H5D_SPACE_STATUS_ALLOCATED = 2} H5D_space_status_t; */
@@ -356,19 +341,13 @@ hid_t create_DT_H5E_direction_t(void);
 /* typedef enum H5E_type_t { H5E_MAJOR, H5E_MINOR} H5E_type_t; */
 hid_t create_DT_H5E_type_t(void);
 
-/* typedef enum H5ES_status_t { H5ES_STATUS_IN_PROGRESS, H5ES_STATUS_SUCCEED, H5ES_STATUS_FAIL, H5ES_STATUS_CANCELED } H5ES_status_t; */
-hid_t create_DT_H5ES_status_t(void);
-
 /* typedef enum H5F_close_degree_t { H5F_CLOSE_DEFAULT = 0, H5F_CLOSE_WEAK = 1, H5F_CLOSE_SEMI = 2, H5F_CLOSE_STRONG = 3} H5F_close_degree_t; */
 hid_t create_DT_H5F_close_degree_t(void);
 
 /* typedef enum H5F_file_space_type_t { H5F_FILE_SPACE_DEFAULT = 0, H5F_FILE_SPACE_ALL_PERSIST = 1, H5F_FILE_SPACE_ALL = 2, H5F_FILE_SPACE_AGGR_VFD = 3, H5F_FILE_SPACE_VFD = 4, H5F_FILE_SPACE_NTYPES } H5F_file_space_type_t; */
 hid_t create_DT_H5F_file_space_type_t(void);
 
-/* typedef enum H5F_fspace_strategy_t { H5F_FSPACE_STRATEGY_FSM_AGGR = 0, H5F_FSPACE_STRATEGY_PAGE = 1, H5F_FSPACE_STRATEGY_AGGR = 2, H5F_FSPACE_STRATEGY_NONE = 3, H5F_FSPACE_STRATEGY_NTYPES } H5F_fspace_strategy_t; */
-hid_t create_DT_H5F_fspace_strategy_t(void);
-
-/* typedef enum H5F_libver_t { H5F_LIBVER_ERROR = -1, H5F_LIBVER_EARLIEST = 0, H5F_LIBVER_V18 = 1, H5F_LIBVER_V110 = 2, H5F_LIBVER_V112 = 3, H5F_LIBVER_NBOUNDS} H5F_libver_t; */
+/* typedef enum H5F_libver_t { H5F_LIBVER_EARLIEST, H5F_LIBVER_LATEST } H5F_libver_t; */
 hid_t create_DT_H5F_libver_t(void);
 
 /* typedef enum H5F_mem_t { H5FD_MEM_NOLIST = -1, H5FD_MEM_DEFAULT = 0, H5FD_MEM_SUPER = 1, H5FD_MEM_BTREE = 2, H5FD_MEM_DRAW = 3, H5FD_MEM_GHEAP = 4, H5FD_MEM_LHEAP = 5, H5FD_MEM_OHDR = 6, H5FD_MEM_NTYPES } H5F_mem_t; */
@@ -386,7 +365,7 @@ hid_t create_DT_H5G_obj_t(void);
 /* typedef enum H5G_storage_type_t { H5G_STORAGE_TYPE_UNKNOWN = -1, H5G_STORAGE_TYPE_SYMBOL_TABLE, H5G_STORAGE_TYPE_COMPACT, H5G_STORAGE_TYPE_DENSE } H5G_storage_type_t; */
 hid_t create_DT_H5G_storage_type_t(void);
 
-/* typedef enum H5I_type_t { H5I_UNINIT = (-2), H5I_BADID = (-1), H5I_FILE = 1, H5I_GROUP, H5I_DATATYPE, H5I_DATASPACE, H5I_DATASET, H5I_MAP, H5I_ATTR, H5I_VFL, H5I_VOL, H5I_GENPROP_CLS, H5I_GENPROP_LST, H5I_ERROR_CLASS, H5I_ERROR_MSG, H5I_ERROR_STACK, H5I_SPACE_SEL_ITER, H5I_NTYPES } H5I_type_t; */
+/* typedef enum H5I_type_t { H5I_UNINIT = (-2), H5I_BADID = (-1), H5I_FILE = 1, H5I_GROUP, H5I_DATATYPE, H5I_DATASPACE, H5I_DATASET, H5I_ATTR, H5I_REFERENCE, H5I_VFL, H5I_GENPROP_CLS, H5I_GENPROP_LST, H5I_ERROR_CLASS, H5I_ERROR_MSG, H5I_ERROR_STACK, H5I_NTYPES } H5I_type_t; */
 hid_t create_DT_H5I_type_t(void);
 
 /* typedef enum { H5L_TYPE_ERROR = (-1), H5L_TYPE_HARD = 0, H5L_TYPE_SOFT = 1, H5L_TYPE_EXTERNAL = 64, H5L_TYPE_MAX = 255 } H5L_type_t; */
@@ -398,19 +377,19 @@ hid_t create_DT_H5LT_lang_t(void);
 /* typedef enum H5O_mcdt_search_ret_t { H5O_MCDT_SEARCH_ERROR = -1, H5O_MCDT_SEARCH_CONT, H5O_MCDT_SEARCH_STOP } H5O_mcdt_search_ret_t; */
 hid_t create_DT_H5O_mcdt_search_ret_t(void);
 
-/* typedef enum H5O_type_t { H5O_TYPE_UNKNOWN = -1, H5O_TYPE_GROUP, H5O_TYPE_DATASET, H5O_TYPE_NAMED_DATATYPE, H5O_TYPE_MAP, H5O_TYPE_NTYPES } H5O_type_t; */
+/* typedef enum H5O_type_t { H5O_TYPE_UNKNOWN = -1, H5O_TYPE_GROUP, H5O_TYPE_DATASET, H5O_TYPE_NAMED_DATATYPE, H5O_TYPE_NTYPES } H5O_type_t; */
 hid_t create_DT_H5O_type_t(void);
 
-/* typedef enum H5PL_type_t { H5PL_TYPE_ERROR = -1, H5PL_TYPE_FILTER = 0, H5PL_TYPE_VOL = 1, H5PL_TYPE_NONE = 2 } H5PL_type_t; */
+/* typedef enum H5PL_type_t { H5PL_TYPE_ERROR = -1, H5PL_TYPE_FILTER = 0, H5PL_TYPE_NONE = 1 } H5PL_type_t; */
 hid_t create_DT_H5PL_type_t(void);
 
-/* typedef enum { H5R_BADTYPE = (-1), H5R_OBJECT1 = 0, H5R_DATASET_REGION1 = 1, H5R_OBJECT2 = 2, H5R_DATASET_REGION2 = 3, H5R_ATTR = 4, H5R_MAXTYPE = 5 } H5R_type_t; */
+/* typedef enum { H5R_BADTYPE = (-1), H5R_OBJECT, H5R_DATASET_REGION, H5R_MAXTYPE } H5R_type_t; */
 hid_t create_DT_H5R_type_t(void);
 
 /* typedef enum H5S_class_t { H5S_NO_CLASS = -1, H5S_SCALAR = 0, H5S_SIMPLE = 1, H5S_NULL = 2 } H5S_class_t; */
 hid_t create_DT_H5S_class_t(void);
 
-/* typedef enum { H5S_SEL_ERROR = -1, H5S_SEL_NONE = 0, H5S_SEL_POINTS = 1, H5S_SEL_HYPERSLABS = 2, H5S_SEL_ALL = 3, H5S_SEL_N } H5S_sel_type; */
+/* typedef enum { H5S_SEL_ERROR = -1, H5S_SEL_NONE = 0, H5S_SEL_POINTS = 1, H5S_SEL_HYPERSLABS = 2, H5S_SEL_ALL = 3, H5S_SEL_N }H5S_sel_type; */
 hid_t create_DT_H5S_sel_type(void);
 
 /* typedef enum H5S_seloper_t { H5S_SELECT_NOOP = -1, H5S_SELECT_SET = 0, H5S_SELECT_OR, H5S_SELECT_AND, H5S_SELECT_XOR, H5S_SELECT_NOTB, H5S_SELECT_NOTA, H5S_SELECT_APPEND, H5S_SELECT_PREPEND, H5S_SELECT_INVALID } H5S_seloper_t; */
@@ -455,12 +434,6 @@ hid_t create_DT_H5T_sign_t(void);
 /* typedef enum H5T_str_t { H5T_STR_ERROR = -1, H5T_STR_NULLTERM = 0, H5T_STR_NULLPAD = 1, H5T_STR_SPACEPAD = 2, H5T_STR_RESERVED_3 = 3, H5T_STR_RESERVED_4 = 4, H5T_STR_RESERVED_5 = 5, H5T_STR_RESERVED_6 = 6, H5T_STR_RESERVED_7 = 7, H5T_STR_RESERVED_8 = 8, H5T_STR_RESERVED_9 = 9, H5T_STR_RESERVED_10 = 10, H5T_STR_RESERVED_11 = 11, H5T_STR_RESERVED_12 = 12, H5T_STR_RESERVED_13 = 13, H5T_STR_RESERVED_14 = 14, H5T_STR_RESERVED_15 = 15 } H5T_str_t; */
 hid_t create_DT_H5T_str_t(void);
 
-/* typedef enum H5VL_map_get_t { H5VL_MAP_GET_MAPL, H5VL_MAP_GET_MCPL, H5VL_MAP_GET_KEY_TYPE, H5VL_MAP_GET_VAL_TYPE, H5VL_MAP_GET_COUNT } H5VL_map_get_t; */
-hid_t create_DT_H5VL_map_get_t(void);
-
-/* typedef enum H5VL_map_specific_t { H5VL_MAP_ITER, H5VL_MAP_DELETE } H5VL_map_specific_t; */
-hid_t create_DT_H5VL_map_specific_t(void);
-
 /* typedef enum H5Z_cb_return_t { H5Z_CB_ERROR = -1, H5Z_CB_FAIL = 0, H5Z_CB_CONT = 1, H5Z_CB_NO = 2} H5Z_cb_return_t; */
 hid_t create_DT_H5Z_cb_return_t(void);
 
@@ -485,9 +458,6 @@ hid_t create_DT_H5A_info_t(void);
 /* typedef struct H5AC_cache_config_t{ int version; hbool_t rpt_fcn_enabled; hbool_t open_trace_file; hbool_t close_trace_file; char trace_file_name[H5AC__MAX_TRACE_FILE_NAME_LEN + 1]; hbool_t evictions_enabled; hbool_t set_initial_size; size_t initial_size; double min_clean_fraction; size_t max_size; size_t min_size; long int epoch_length; enum H5C_cache_incr_mode incr_mode; double lower_hr_threshold; double increment; hbool_t apply_max_increment; size_t max_increment; enum H5C_cache_flash_incr_mode flash_incr_mode; double flash_multiple; double flash_threshold; enum H5C_cache_decr_mode decr_mode; double upper_hr_threshold; double decrement; hbool_t apply_max_decrement; size_t max_decrement; int epochs_before_eviction; hbool_t apply_empty_reserve; double empty_reserve; size_t dirty_bytes_threshold; int metadata_write_strategy} H5AC_cache_config_t; */
 hid_t create_DT_H5AC_cache_config_t(void);
 
-/* typedef struct H5AC_cache_image_config_t { int version; hbool_t generate_image; hbool_t save_resize_status; int entry_ageout} H5AC_cache_image_config_t; */
-hid_t create_DT_H5AC_cache_image_config_t(void);
-
 /* typedef struct H5D_info_t { int rank; char* dims; char* maxdims; H5T_class_t type_class; H5S_class_t space_class} H5D_info_t; */
 hid_t create_DT_H5D_info_t(void);
 
@@ -497,7 +467,7 @@ hid_t create_DT_H5E_error1_t(void);
 /* typedef struct H5E_error2_t { hid_t cls_id; hid_t maj_num; hid_t min_num; unsigned line; const char *func_name; const char *file_name; const char *desc} H5E_error2_t; */
 hid_t create_DT_H5E_error2_t(void);
 
-/* typedef struct H5F_info1_helper_t { hsize_t hdr_size; H5_ih_info_t msgs_info} H5F_info1_helper_t; */
+/* typedef struct H5F_info1_helper_t { hsize_t hdr_size; H5_ih_info_t msgs_info} H5F_info1_helper_t;  */
 hid_t create_DT_H5F_info1_helper_t(void);
 
 /* typedef struct H5F_info1_t { hsize_t super_ext_size; H5F_info1_helper_t sohm} H5F_info1_t; */
@@ -524,57 +494,33 @@ hid_t create_DT_H5F_sect_info_t(void);
 /* typedef struct H5G_info_t { H5G_storage_type_t storage_type; hsize_t nlinks; int64_t max_corder; hbool_t mounted} H5G_info_t; */
 hid_t create_DT_H5G_info_t(void);
 
-/* typedef union H5L_info1_helper_t { haddr_t address; size_t val_size} H5L_info1_helper_t; */
-hid_t create_DT_H5L_info1_helper_t(void);
+/* typedef union H5L_info_helper_t { haddr_t address; size_t val_size} H5L_info_helper_t;  */
+hid_t create_DT_H5L_info_helper_t(void);
 
-/* typedef struct H5L_info1_t { H5L_type_t type; hbool_t corder_valid; int64_t corder; H5T_cset_t cset; H5L_info1_helper_t u} H5L_info1_t; */
-hid_t create_DT_H5L_info1_t(void);
+/* typedef struct H5L_info_t { H5L_type_t type; hbool_t corder_valid; int64_t corder; H5T_cset_t cset; H5L_info_helper_t u} H5L_info_t; */
+hid_t create_DT_H5L_info_t(void);
 
-/* typedef union H5L_info2_helper_t { H5O_token_t token; size_t val_size} H5L_info2_helper_t; */
-hid_t create_DT_H5L_info2_helper_t(void);
-
-/* typedef struct H5L_info2_t { H5L_type_t type; hbool_t corder_valid; int64_t corder; H5T_cset_t cset; H5L_info2_helper_t u} H5L_info2_t; */
-hid_t create_DT_H5L_info2_t(void);
-
-/* typedef struct H5ls_info_t { char* name; int link_success; H5L_info1_t link; int obj_type_success; H5I_type_t obj_type; int num_attrs; int group_success; H5G_info_t group; int dataset_success; H5D_info_t dataset; int type_success; H5T_class_t committed_type} H5ls_info_t; */
+/* typedef struct H5ls_info_t { char* name; int link_success; H5L_info_t link; int obj_type_success; H5I_type_t obj_type; int num_attrs; int group_success; H5G_info_t group; int dataset_success; H5D_info_t dataset; int type_success; H5T_class_t committed_type} H5ls_info_t; */
 hid_t create_DT_H5ls_info_t(void);
 
-/* typedef struct H5O_hdr_info_helper_msg_t { uint64_t present; uint64_t shared} H5O_hdr_info_helper_msg_t; */
+/* typedef struct H5O_hdr_info_helper_msg_t { uint64_t present; uint64_t shared} H5O_hdr_info_helper_msg_t;  */
 hid_t create_DT_H5O_hdr_info_helper_msg_t(void);
 
-/* typedef struct H5O_hdr_info_helper_space_t { hsize_t total; hsize_t meta; hsize_t mesg; hsize_t free} H5O_hdr_info_helper_space_t; */
+/* typedef struct H5O_hdr_info_helper_space_t { hsize_t total; hsize_t meta; hsize_t mesg; hsize_t free} H5O_hdr_info_helper_space_t;  */
 hid_t create_DT_H5O_hdr_info_helper_space_t(void);
 
 /* typedef struct H5O_hdr_info_t { unsigned version; unsigned nmesgs; unsigned nchunks; unsigned flags; H5O_hdr_info_helper_space_t space; H5O_hdr_info_helper_msg_t mesg} H5O_hdr_info_t; */
 hid_t create_DT_H5O_hdr_info_t(void);
 
-/* typedef struct H5O_info_helper_t { H5_ih_info_t obj; H5_ih_info_t attr} H5O_info_helper_t; */
+/* typedef struct H5O_info_helper_t { H5_ih_info_t obj; H5_ih_info_t attr} H5O_info_helper_t;  */
 hid_t create_DT_H5O_info_helper_t(void);
 
-/* typedef struct H5O_info1_t { unsigned long fileno; haddr_t addr; H5O_type_t type; unsigned rc; time_t atime; time_t mtime; time_t ctime; time_t btime; hsize_t num_attrs; H5O_hdr_info_t hdr; H5O_info_helper_t meta_size} H5O_info1_t; */
-hid_t create_DT_H5O_info1_t(void);
-
-/* typedef struct H5O_info2_t { unsigned long fileno; H5O_token_t token; H5O_type_t type; unsigned rc; time_t atime; time_t mtime; time_t ctime; time_t btime; hsize_t num_attrs} H5O_info2_t; */
-hid_t create_DT_H5O_info2_t(void);
-
-/* typedef struct H5O_native_info_t { H5O_hdr_info_t hdr; H5O_info_helper_t meta_size} H5O_native_info_t; */
-hid_t create_DT_H5O_native_info_t(void);
+/* typedef struct H5O_info_t { unsigned long fileno; haddr_t addr; H5O_type_t type; unsigned rc; time_t atime; time_t mtime; time_t ctime; time_t btime; hsize_t num_attrs; H5O_hdr_info_t hdr; H5O_info_helper_t meta_size} H5O_info_t; */
+hid_t create_DT_H5O_info_t(void);
 
 /* typedef struct H5O_stat_t { hsize_t size; hsize_t free; unsigned nmesgs; unsigned nchunks} H5O_stat_t; */
 hid_t create_DT_H5O_stat_t(void);
 
-/* typedef struct H5O_token_t { uint8_t __data[H5O_MAX_TOKEN_SIZE]} H5O_token_t; */
-hid_t create_DT_H5O_token_t(void);
-
-/* typedef struct H5R_ref_helper_t { uint64_t part0; uint64_t part1; uint64_t part2; uint64_t part3; uint64_t part4; uint64_t part5; uint64_t part6; uint64_t part7} H5R_ref_helper_t; */
-hid_t create_DT_H5R_ref_helper_t(void);
-
-/* typedef struct H5R_ref_t { H5R_ref_helper_t u} H5R_ref_t; */
-hid_t create_DT_H5R_ref_t(void);
-
-/* typedef struct { uint8_t __data[H5R_DSET_REG_REF_BUF_SIZE]} hdset_reg_ref_t; */
-hid_t create_DT_hdset_reg_ref_t(void);
-
 
 
 #endif
