@@ -7,8 +7,6 @@ SEXP R_H5Gclose(SEXP R_group_id);
 SEXP R_H5Gcreate_anon(SEXP R_loc_id, SEXP R_gcpl_id, SEXP R_gapl_id);
 /* H5_DLL hid_t H5Gcreate2(hid_t loc_id, const char *name, hid_t lcpl_id, hid_t gcpl_id, hid_t gapl_id); */
 SEXP R_H5Gcreate2(SEXP R_loc_id, SEXP R_name, SEXP R_lcpl_id, SEXP R_gcpl_id, SEXP R_gapl_id);
-/* H5_DLL herr_t H5Gflush(hid_t group_id); */
-SEXP R_H5Gflush(SEXP R_group_id);
 /* H5_DLL hid_t H5Gget_create_plist(hid_t group_id); */
 SEXP R_H5Gget_create_plist(SEXP R_group_id);
 /* H5_DLL herr_t H5Gget_info(hid_t loc_id, H5G_info_t *ginfo); */
@@ -19,8 +17,6 @@ SEXP R_H5Gget_info_by_idx(SEXP R_loc_id, SEXP R_group_name, SEXP R_idx_type, SEX
 SEXP R_H5Gget_info_by_name(SEXP R_loc_id, SEXP R_name, SEXP R_ginfo, SEXP R_lapl_id);
 /* H5_DLL hid_t H5Gopen2(hid_t loc_id, const char *name, hid_t gapl_id); */
 SEXP R_H5Gopen2(SEXP R_loc_id, SEXP R_name, SEXP R_gapl_id);
-/* H5_DLL herr_t H5Grefresh(hid_t group_id); */
-SEXP R_H5Grefresh(SEXP R_group_id);
 /* H5_DLL herr_t H5Gset_comment(hid_t loc_id, const char *name, const char *comment); */
 SEXP R_H5Gset_comment(SEXP R_loc_id, SEXP R_name, SEXP R_comment);
 #endif
